

create table laender(
nummer             smallint not null check ($>=1 and $<=99) label "Nummer",
lname              char(   20) label "Name") 
	primary key (nummer)
;


create table einheiten(
einheit            char(    2) not null label "Einheit",
bezeichung         char(   10) label "Bezeichnung") 
	primary key (einheit)
;


create table zahlbed(
schluessel         char(    2) not null label "Schlssel",
bezeichnung        char(   20) label "Bezeichnung") 
	primary key (schluessel)
;


create table liefer(
nummer             integer not null label "Nummer",
nachname           char(   25) not null label "Nachname",
vorname            char(   15) label "Vorname",
firma              char(   30) not null label "Firma",
adresse1           char(   25) not null label "Adresse 1",
adresse2           char(   25) label "Adresse 2",
ort                char(   30) label "Plz/Ort",
telefon            char(   15) label "Telefon",
land               smallint not null format "1" label "Land") 
	primary key (nummer)
;
create index i2_liefer on liefer(firma      );


create table artikel(
nummer             char(   12) not null label "Artikel-Nummer",
liefer             integer not null label "Lieferant",
bezeichnung        char(   15) not null label "Bezeichnung",
vkpreis            money(  8,  2) label "Verkaufspreis",
ekpreis            money(  8,  2) label "Einkaufspreis",
einheit            char(    2) not null default "St" label "Einheit",
bestand            smallint label "Lagerbestand",
minbestand         smallint label "Mindestbestand",
maxbestand         smallint label "Maximalbestand",
zugang             date label "Letzter Zugang",
abgang             date label "Letzter Abgang") 
	primary key (nummer,liefer)
;
create index i2_artikel on artikel(nummer      );
create index i3_artikel on artikel(liefer      );
create index i4_artikel on artikel(bezeichnung      );


create table kunden(
nummer             integer not null label "Kd-Nr.",
nachname           char(   25) not null label "Nachname",
vorname            char(   15) label "Vorname",
firma              char(   30) not null label "Firma",
adresse1           char(   25) label "Adresse 1",
adresse2           char(   25) label "Adresse 2",
ort                char(   30) label "Plz/Ort",
land               smallint not null default "1" label "Land",
telefon            char(   15) label "Telefon",
zahlbed            char(    2) not null upshift default "SO" label "Zahlungsbedingung",
ges_umsatz         money( 10,  2) label "Umsatz") 
	primary key (nummer)
;
create index i2_kunden on kunden(firma      );


create table zeilen(
re_nummer          integer not null label "Re-Nr.",
zeile              smallint not null label "Zeile",
artnr              char(   12) not null label "Artikel-Nr.",
liefnr             integer not null label "Lieferant",
menge              smallint label "Menge",
preis              money(  8,  2) label "Einzelpreis",
rabatt             smallint label "Rabatt") 
	primary key (re_nummer,zeile)
;
create index i2_zeilen on zeilen(re_nummer      );


create table rechnungen(
re_nummer          integer not null label "Re-Nr.",
kdnr               integer not null label "Kunden-Nr.",
re_dat             date label "Rechnungsdatum",
lief_dat           date label "Lieferdatum",
zahl_dat           date label "Zahlungstermin",
zahlbed            char(    2) not null label "Zahlungsbedingung",
rstatus            char(    1) check ($ in ("J","N")) label "Status") 
	primary key (re_nummer)
;
create index i2_rechnungen on rechnungen(kdnr      );
alter table liefer             
	foreign key fk1_liefer(land) 	references laender
	on update restrict 
	on delete restrict 
;

alter table artikel            
	foreign key fk2_artikel(einheit) 	references einheiten
	on update restrict 
	on delete restrict 
;

alter table artikel            
	foreign key fk1_artikel(liefer) 	references liefer
	on update restrict 
	on delete restrict 
;

alter table kunden             
	foreign key fk2_kunden(zahlbed) 	references zahlbed
	on update restrict 
	on delete restrict 
;

alter table kunden             
	foreign key fk1_kunden(land) 	references laender
	on update restrict 
	on delete restrict 
;

alter table zeilen             
	foreign key fk2_zeilen(re_nummer) 	references rechnungen
	on update restrict 
	on delete restrict 
;

alter table zeilen             
	foreign key fk1_zeilen(artnr,liefnr) 	references artikel
	on update restrict 
	on delete restrict 
;

alter table rechnungen         
	foreign key fk2_rechnungen(zahlbed) 	references zahlbed
	on update restrict 
	on delete restrict 
;

alter table rechnungen         
	foreign key fk1_rechnungen(kdnr) 	references kunden
	on update restrict 
	on delete restrict 
;


create view art_fakt (text, gesamt)
as select 
	bezeichnung, sum (preis * (1 - rabatt / 100) * menge)
	from zeilen, artikel, rechnungen
	where artikel.nummer = zeilen.artnr and
	zeilen.liefnr= artikel.liefer and
	rechnungen.re_nummer = zeilen.re_nummer and
	rechnungen.rstatus = "J"
	group by 1	
;

